/*  Gringotts - a small utility to safe-keep sensitive data
 *  (c) 2002, Germano Rizzo <mano@pluto.linux.it>
 *
 *  grg_recent_dox.c - manages the recently-opened-docs list
 *  Author: Germano Rizzo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <string.h>

#include <glib.h>

#include "grg_recent_dox.h"
#include "grg_utils.h"
#include "grg_menus.h"
#include "grg_defs.h"

GSList *grg_recent_dox = NULL;

void
grg_recent_dox_init (void)
{
	guchar *path, sfile[256];
	FILE *fp;

	path = g_build_filename (g_get_home_dir (), ".gringotts.recent", NULL);
	fp = fopen (path, "r");
	g_free (path);

	if (!fp)
		return;

	while(TRUE)
	{
		//skip first line
		if (!skip_lines (fp, 2))
			break;
		if(fgets(sfile, 255, fp) == NULL)
			break;
		g_strstrip(sfile);
		if(g_slist_length (grg_recent_dox) == GRG_RECENT_LIMIT)
			break;
		if(g_file_test(sfile, G_FILE_TEST_EXISTS))
			grg_recent_dox = g_slist_append(grg_recent_dox, g_strdup(sfile));
	}

	fclose (fp);
}

void
grg_recent_dox_deinit (void)
{
	g_slist_foreach (grg_recent_dox, (GFunc) g_free, NULL);
	g_slist_free (grg_recent_dox);
}

static void
recent_dox_save (void)
{
	guchar *path, *row, i=1;
	GSList *cur;
	FILE *fp;

	path = g_build_filename (g_get_home_dir (), ".gringotts.recent", NULL);
	fp = fopen (path, "w");
	g_free (path);

	if (!fp)
		return;

	//writes an header
	row = "<!-- this isn't (yet) true XML. It's *very* positional, so please leave it as it is -->\n";
	fwrite (row, strlen (row), 1, fp);

	cur = grg_recent_dox;
	
	while ((cur != NULL) && (i<=GRG_RECENT_LIMIT))
	{
		row = g_strdup_printf ("<file pos=\"%d\">\n%s\n</file>\n", i, (guchar *)cur->data);
		fwrite (row, strlen (row), 1, fp);
		g_free (row);
		cur = cur->next;
		i++;
	}
	
	fclose (fp);

	return;
}

void
grg_recent_dox_push (const guchar* file)
{
	GSList *cur, *tmp;

	if(file == NULL)
		return;
	
	tmp = grg_recent_dox;
	while(tmp)
	{
		cur = tmp;
		tmp = tmp->next;
		if ((strcmp(cur->data, file) == 0) ||
			(g_slist_position (grg_recent_dox, cur) >= GRG_RECENT_LIMIT-1))
		{
			grg_recent_dox = g_slist_remove_link (grg_recent_dox, cur);
			g_free (cur->data);
			g_slist_free_1 (cur);
		}
	}

	grg_recent_dox = g_slist_prepend (grg_recent_dox, g_strdup((guchar*) file));

	recent_dox_save ();
	grg_menu_update ();
}
